/**
 * 
 */
package edu.wisc.uwss.configuration.local;

import java.io.IOException;
import java.util.Properties;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.config.PropertiesFactoryBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import org.springframework.core.io.ClassPathResource;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.method.configuration.EnableGlobalMethodSecurity;
import org.springframework.security.config.annotation.method.configuration.GlobalMethodSecurityConfiguration;
import org.springframework.security.core.userdetails.UserDetailsService;

import edu.wisc.uwss.local.LocalUserDetailsServiceImpl;

/**
 * @author Nicholas Blair
 */
@Configuration
@Profile("local-users")
@EnableGlobalMethodSecurity(prePostEnabled = true)
public class LocalAuthenticationSecurityConfiguration extends GlobalMethodSecurityConfiguration {
  /**
   * Inject our custom {@link UserDetailsService} into the {@link AuthenticationManagerBuilder}.
   * 
   * @param auth
   * @param userDetailsService
   * @throws Exception
   */
  @Autowired
  public void configureGlobal(AuthenticationManagerBuilder auth, UserDetailsService userDetailsService) throws Exception { 
    auth.userDetailsService(userDetailsService);
  }
  /**
   * 
   * @return a {@link LocalUserDetailsServiceImpl}
   */
  @Bean
  public UserDetailsService localUserDetailsService() {
    return new LocalUserDetailsServiceImpl();
  }
  /**
   * 
   * @return a {@link Properties} instance containing all local user accounts.
   */
  @Bean @Qualifier("demo-users")
  public Properties demoUserProperties() {
      PropertiesFactoryBean propertiesFactoryBean = new PropertiesFactoryBean();
      propertiesFactoryBean.setLocation(new ClassPathResource("edu/wisc/uwss/local/local-users.properties"));
      Properties properties = null;
      try {
          propertiesFactoryBean.afterPropertiesSet();
          properties = propertiesFactoryBean.getObject();
      } catch (IOException e) {
          throw new IllegalStateException("unable to load demo-users.properties from classpath", e);
      }
      return properties;
  }

}
