/**
 * 
 */
package edu.wisc.uwss.configuration.local;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;

/**
 * {@link Configuration} for the "local-users" {@link Profile}.
 * 
 * @author Nicholas Blair
 */
@Configuration
@EnableWebSecurity
@Profile("local-users")
public class WebSecurityConfiguration extends WebSecurityConfigurerAdapter {

  protected final Logger logger = LoggerFactory.getLogger(this.getClass());
  /**
   * {@inheritDoc}
   * 
   * Enables {@link HttpSecurity#formLogin()} and {@link HttpSecurity#httpBasic()} for demo users.
   */
  @Override
  protected void configure(HttpSecurity http) throws Exception { 
    logger.debug("enter WebSecurityConfigurerAdapter#configure for local-users");
    http
      .formLogin()
        .and()
      .httpBasic()
        .and()
      .logout()
        .invalidateHttpSession(true);
    
    // CSRF protection is disabled, as without it /logout requires POST
    http
      .csrf().disable();
  }

  /**
   * Exposes the internal {@link HttpSecurity} as a bean so deployers can customize it further.
   * 
   * @return
   * @throws Exception
   */
  @Bean
  public HttpSecurity httpSecurity() throws Exception {
    return getHttp();
  }
}
