/**
 * 
 */
package edu.wisc.uwss;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;

import org.apache.commons.lang3.StringUtils;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.User;
import org.springframework.util.DigestUtils;

/**
 * Implementation of {@link UWUserDetails} returned by the demo services in this package.
 * 
 * @author Nicholas Blair
 */
public class UWUserDetailsImpl extends User implements UWUserDetails {

  /**
   * 
   */
  private static final long serialVersionUID = -8120331081953321708L;

  private final String pvi;
  private final String fullName;
  private final Collection<String> uddsMembership;
  private final String emailAddress;
  private final String emailAddressHash;
  private String source;
  private String customLogoutUrl;

  /**
   * 
   * @param pvi
   * @param username
   * @param password
   * @param fullName
   * @param emailAddress
   */
  public UWUserDetailsImpl(String pvi, String username, String password,
      String fullName, String emailAddress) {
    this(pvi, username, password, fullName, emailAddress, Collections
        .<String> emptyList());
  }

  /**
   * 
   * @param pvi
   * @param username
   * @param password
   * @param fullName
   * @param uddsMembership
   */
  public UWUserDetailsImpl(String pvi, String username, String password,
      String fullName, String emailAddress,
      Collection<String> uddsMembership) {
    super(username, password, Collections.<GrantedAuthority> emptyList());
    this.pvi = pvi;
    this.fullName = fullName;
    this.uddsMembership = uddsMembership;
    this.emailAddress = emailAddress;
    this.emailAddressHash = StringUtils.isNotBlank(emailAddress) ? DigestUtils
        .md5DigestAsHex(emailAddress.toLowerCase().getBytes()) : null;
  }


  /**
   * Clone style constructor.
   * 
   * @param original
   */
  public UWUserDetailsImpl(UWUserDetailsImpl original) {
    this(original.getPvi(), original.getUsername(), original.getPassword(), original
        .getFullName(), original.getEmailAddress(), original
        .getUddsMembership());
    setSource(original.getSource());
  }

  /* (non-Javadoc)
   * @see edu.wisc.uwss.UWUserDetails#getPvi()
   */
  @Override
  public String getPvi() {
    return this.pvi;
  }

  public String getFullName() {
    return this.fullName;
  }

  public Collection<String> getUddsMembership() {
    return uddsMembership;
  }

  public String getSource() {
    return source;
  }
  /**
   * @param source the source to set
   */
  public void setSource(String source) {
    this.source = source;
  }
  
  public String getCustomLogoutUrl() {
    return customLogoutUrl;
  }
  /**
   * @param customLogoutUrl the customLogoutUrl to set
   */
  public void setCustomLogoutUrl(String customLogoutUrl) {
    this.customLogoutUrl = customLogoutUrl;
  }

  public String getEmailAddress() {
    return this.emailAddress;
  }

  /**
   * Returns MD5 hash of {@link #getEmailAddress()} in Hex.
   * 
   * @return the MD5 hash of {@link #getEmailAddress()} if not blank,
   *         otherwise null
   */
  public final String getEmailAddressHash() {
    return this.emailAddressHash;
  }
  /**
   * {@inheritDoc}
   * 
   * Copied super's toString, but modified how {@link #getAuthorities()} is
   * represented.
   */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("PVI: ").append(getPvi()).append("; ");
    sb.append("Username: ").append(getUsername()).append("; ");
    sb.append("Password: [PROTECTED]; ");
    sb.append("Enabled: ").append(isEnabled()).append("; ");
    sb.append("AccountNonExpired: ").append(isAccountNonExpired())
    .append("; ");
    sb.append("credentialsNonExpired: ").append(isCredentialsNonExpired())
    .append("; ");
    sb.append("AccountNonLocked: ").append(isAccountNonLocked())
    .append("; ");
    sb.append("Authorities: ")
    .append(Arrays.toString(getAuthorities().toArray()))
    .append("; ");
    sb.append("Source: ").append(getSource()).append("; ");
    sb.append("Custom Logout Url: ").append(getCustomLogoutUrl());
    return sb.toString();
  }

}
